@@ -102,14 +102,23 @@ class Dbt:
                         )
                     model_file.write(stmt)
 
-    def run(self, incremental: bool = False):
+    def run(self, select: str = "", exclude: str = "", incremental: bool = False):
         """Compile the sql files then runs DBT
 
         Args:
+            select (str): use it the same way you would use the select flag with the dbt CLI
+            exclude (str): use it the same way you would use the exclude flag with the dbt CLI
             incremental (bool): when True, make the DBT models incremental
         """
         self.transpile(incremental)
-        subprocess.run(["dbt", "run", "--fail-fast"], env=os.environ.copy())  # nosec
+        cmd = ["dbt", "run", "--fail-fast"]
+        if select:
+            cmd.append("--select")
+            cmd.append(select)
+        if exclude:
+            cmd.append("--exclude")
+            cmd.append(exclude)
+        subprocess.run(cmd, env=os.environ.copy())  # nosec
 
     def refresh(self):
         """Refresh DBT incremental models"""
